package com.cn.fdapfe.biz.service;

import java.io.IOException;
import java.util.List;
import java.util.Map;

import com.cn.fdapfe.biz.domain.FdAlgorithm;

/**
 * 故障诊断算法功能验证Service接口
 * 
 * @author Allen
 * @date 2025-03-07
 */
public interface IFdAlgorithmService 
{
    /**
     * 查询故障诊断算法功能验证
     * 
     * @param id 故障诊断算法功能验证主键
     * @return 故障诊断算法功能验证
     */
     FdAlgorithm selectFdAlgorithmById(String id);

    /**
     * 查询故障诊断算法功能验证列表
     * 
     * @param fdAlgorithm 故障诊断算法功能验证
     * @return 故障诊断算法功能验证集合
     */
     List<FdAlgorithm> selectFdAlgorithmList(FdAlgorithm fdAlgorithm);

    /**
     * 新增故障诊断算法功能验证
     * 
     * @param fdAlgorithm 故障诊断算法功能验证
     * @return 结果
     */
     int insertFdAlgorithm(FdAlgorithm fdAlgorithm) throws IOException, InterruptedException;

    /**
     * 修改故障诊断算法功能验证
     * 
     * @param fdAlgorithm 故障诊断算法功能验证
     * @return 结果
     */
     int updateFdAlgorithm(FdAlgorithm fdAlgorithm) throws IOException, InterruptedException;

    /**
     * 批量删除故障诊断算法功能验证
     * 
     * @param ids 需要删除的故障诊断算法功能验证主键集合
     * @return 结果
     */
     int deleteFdAlgorithmByIds(String[] ids);

    /**
     * 验证，
     * @param po
     * @return
     * @throws IOException
     * @throws InterruptedException
     */
    Map handleVerify(FdAlgorithm po) throws IOException, InterruptedException;

    List<Map<String,Object>> getOptions();
}
